# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_chatbot.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x61ws/aws_chatbot.proto\x12\x17oak9.tython.aws.chatbot\x1a\x13shared/shared.proto\"\xeb\x01\n\x19SlackChannelConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12slack_workspace_id\x18\x02 \x01(\t\x12\x18\n\x10slack_channel_id\x18\x03 \x01(\t\x12\x1a\n\x12\x63onfiguration_name\x18\x04 \x01(\t\x12\x14\n\x0ciam_role_arn\x18\x05 \x01(\t\x12\x16\n\x0esns_topic_arns\x18\x06 \x03(\t\x12\x15\n\rlogging_level\x18\x07 \x01(\t\"b\n\x07\x43hatbot\x12W\n\x1bslack_channel_configuration\x18\x01 \x03(\x0b\x32\x32.oak9.tython.aws.chatbot.SlackChannelConfigurationb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_chatbot_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SLACKCHANNELCONFIGURATION._serialized_start=72
  _SLACKCHANNELCONFIGURATION._serialized_end=307
  _CHATBOT._serialized_start=309
  _CHATBOT._serialized_end=407
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_route53.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x61ws/aws_route53.proto\x12\x17oak9.tython.aws.route53\x1a\x13shared/shared.proto\"p\n\x19HealthCheckHealthCheckTag\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xa9\x02\n\x0bHealthCheck\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12X\n\x13health_check_config\x18\x02 \x03(\x0b\x32;.oak9.tython.aws.route53.HealthCheck.HealthCheckConfigEntry\x12M\n\x11health_check_tags\x18\x03 \x03(\x0b\x32\x32.oak9.tython.aws.route53.HealthCheckHealthCheckTag\x1a\x38\n\x16HealthCheckConfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfa\x01\n\x07Route53\x12:\n\x0chealth_check\x18\x01 \x03(\x0b\x32$.oak9.tython.aws.route53.HealthCheck\x12\x38\n\x0bhosted_zone\x18\x02 \x01(\x0b\x32#.oak9.tython.aws.route53.HostedZone\x12\x36\n\nrecord_set\x18\x03 \x03(\x0b\x32\".oak9.tython.aws.route53.RecordSet\x12\x41\n\x10record_set_group\x18\x04 \x01(\x0b\x32\'.oak9.tython.aws.route53.RecordSetGroup\"f\n\x1aHostedZoneHostedZoneConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63omment\x18\x02 \x01(\t\"n\n\x17HostedZoneHostedZoneTag\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\x7f\n\x1cHostedZoneQueryLoggingConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12&\n\x1e\x63loud_watch_logs_log_group_arn\x18\x02 \x01(\t\"l\n\rHostedZoneVPC\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06vpc_id\x18\x02 \x01(\t\x12\x12\n\nvpc_region\x18\x03 \x01(\t\"\xfb\x02\n\nHostedZone\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12O\n\x12hosted_zone_config\x18\x02 \x01(\x0b\x32\x33.oak9.tython.aws.route53.HostedZoneHostedZoneConfig\x12J\n\x10hosted_zone_tags\x18\x03 \x03(\x0b\x32\x30.oak9.tython.aws.route53.HostedZoneHostedZoneTag\x12\x0c\n\x04name\x18\x04 \x01(\t\x12S\n\x14query_logging_config\x18\x05 \x01(\x0b\x32\x35.oak9.tython.aws.route53.HostedZoneQueryLoggingConfig\x12\x34\n\x04vpcs\x18\x06 \x03(\x0b\x32&.oak9.tython.aws.route53.HostedZoneVPC\"\x99\x01\n\x14RecordSetAliasTarget\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08\x64ns_name\x18\x02 \x01(\t\x12\x1e\n\x16\x65valuate_target_health\x18\x03 \x01(\x08\x12\x16\n\x0ehosted_zone_id\x18\x04 \x01(\t\"\x97\x01\n\x14RecordSetGeoLocation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x63ontinent_code\x18\x02 \x01(\t\x12\x14\n\x0c\x63ountry_code\x18\x03 \x01(\t\x12\x18\n\x10subdivision_code\x18\x04 \x01(\t\"\xd3\x03\n\tRecordSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x43\n\x0c\x61lias_target\x18\x02 \x01(\x0b\x32-.oak9.tython.aws.route53.RecordSetAliasTarget\x12\x0f\n\x07\x63omment\x18\x03 \x01(\t\x12\x10\n\x08\x66\x61ilover\x18\x04 \x01(\t\x12\x43\n\x0cgeo_location\x18\x05 \x01(\x0b\x32-.oak9.tython.aws.route53.RecordSetGeoLocation\x12\x17\n\x0fhealth_check_id\x18\x06 \x01(\t\x12\x16\n\x0ehosted_zone_id\x18\x07 \x01(\t\x12\x18\n\x10hosted_zone_name\x18\x08 \x01(\t\x12\x1a\n\x12multi_value_answer\x18\t \x01(\x08\x12\x0c\n\x04name\x18\n \x01(\t\x12\x0e\n\x06region\x18\x0b \x01(\t\x12\x18\n\x10resource_records\x18\x0c \x03(\t\x12\x16\n\x0eset_identifier\x18\r \x01(\t\x12\x0b\n\x03ttl\x18\x0e \x01(\t\x12\x0c\n\x04type\x18\x0f \x01(\t\x12\x0e\n\x06weight\x18\x10 \x01(\x05\"\x9e\x01\n\x19RecordSetGroupAliasTarget\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08\x64ns_name\x18\x02 \x01(\t\x12\x1e\n\x16\x65valuate_target_health\x18\x03 \x01(\x08\x12\x16\n\x0ehosted_zone_id\x18\x04 \x01(\t\"\x9c\x01\n\x19RecordSetGroupGeoLocation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x63ontinent_code\x18\x02 \x01(\t\x12\x14\n\x0c\x63ountry_code\x18\x03 \x01(\t\x12\x18\n\x10subdivision_code\x18\x04 \x01(\t\"\xdd\x03\n\x17RecordSetGroupRecordSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12H\n\x0c\x61lias_target\x18\x02 \x01(\x0b\x32\x32.oak9.tython.aws.route53.RecordSetGroupAliasTarget\x12\x0f\n\x07\x63omment\x18\x03 \x01(\t\x12\x10\n\x08\x66\x61ilover\x18\x04 \x01(\t\x12H\n\x0cgeo_location\x18\x05 \x01(\x0b\x32\x32.oak9.tython.aws.route53.RecordSetGroupGeoLocation\x12\x17\n\x0fhealth_check_id\x18\x06 \x01(\t\x12\x16\n\x0ehosted_zone_id\x18\x07 \x01(\t\x12\x18\n\x10hosted_zone_name\x18\x08 \x01(\t\x12\x1a\n\x12multi_value_answer\x18\t \x01(\x08\x12\x0c\n\x04name\x18\n \x01(\t\x12\x0e\n\x06region\x18\x0b \x01(\t\x12\x18\n\x10resource_records\x18\x0c \x03(\t\x12\x16\n\x0eset_identifier\x18\r \x01(\t\x12\x0b\n\x03ttl\x18\x0e \x01(\t\x12\x0e\n\x06weight\x18\x0f \x01(\x05\"\xd3\x01\n\x0eRecordSetGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63omment\x18\x02 \x01(\t\x12\x16\n\x0ehosted_zone_id\x18\x03 \x01(\t\x12\x18\n\x10hosted_zone_name\x18\x04 \x01(\t\x12\x45\n\x0brecord_sets\x18\x05 \x03(\x0b\x32\x30.oak9.tython.aws.route53.RecordSetGroupRecordSetb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_route53_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _HEALTHCHECK_HEALTHCHECKCONFIGENTRY._options = None
  _HEALTHCHECK_HEALTHCHECKCONFIGENTRY._serialized_options = b'8\001'
  _HEALTHCHECKHEALTHCHECKTAG._serialized_start=71
  _HEALTHCHECKHEALTHCHECKTAG._serialized_end=183
  _HEALTHCHECK._serialized_start=186
  _HEALTHCHECK._serialized_end=483
  _HEALTHCHECK_HEALTHCHECKCONFIGENTRY._serialized_start=427
  _HEALTHCHECK_HEALTHCHECKCONFIGENTRY._serialized_end=483
  _ROUTE53._serialized_start=486
  _ROUTE53._serialized_end=736
  _HOSTEDZONEHOSTEDZONECONFIG._serialized_start=738
  _HOSTEDZONEHOSTEDZONECONFIG._serialized_end=840
  _HOSTEDZONEHOSTEDZONETAG._serialized_start=842
  _HOSTEDZONEHOSTEDZONETAG._serialized_end=952
  _HOSTEDZONEQUERYLOGGINGCONFIG._serialized_start=954
  _HOSTEDZONEQUERYLOGGINGCONFIG._serialized_end=1081
  _HOSTEDZONEVPC._serialized_start=1083
  _HOSTEDZONEVPC._serialized_end=1191
  _HOSTEDZONE._serialized_start=1194
  _HOSTEDZONE._serialized_end=1573
  _RECORDSETALIASTARGET._serialized_start=1576
  _RECORDSETALIASTARGET._serialized_end=1729
  _RECORDSETGEOLOCATION._serialized_start=1732
  _RECORDSETGEOLOCATION._serialized_end=1883
  _RECORDSET._serialized_start=1886
  _RECORDSET._serialized_end=2353
  _RECORDSETGROUPALIASTARGET._serialized_start=2356
  _RECORDSETGROUPALIASTARGET._serialized_end=2514
  _RECORDSETGROUPGEOLOCATION._serialized_start=2517
  _RECORDSETGROUPGEOLOCATION._serialized_end=2673
  _RECORDSETGROUPRECORDSET._serialized_start=2676
  _RECORDSETGROUPRECORDSET._serialized_end=3153
  _RECORDSETGROUP._serialized_start=3156
  _RECORDSETGROUP._serialized_end=3367
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import gcp.gcp_compute_subnetwork_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GoogleComputeSubnetwork(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPUTE_SUBNETWORK_FIELD_NUMBER: builtins.int
    COMPUTE_SUBNETWORK_IAM_BINDING_FIELD_NUMBER: builtins.int
    COMPUTE_SUBNETWORK_IAM_MEMBER_FIELD_NUMBER: builtins.int
    COMPUTE_SUBNETWORK_IAM_POLICY_FIELD_NUMBER: builtins.int
    @property
    def compute_subnetwork(self) -> gcp.gcp_compute_subnetwork_pb2.ComputeSubnetwork: ...
    @property
    def compute_subnetwork_iam_binding(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_compute_subnetwork_pb2.ComputeSubnetworkIamBinding]: ...
    @property
    def compute_subnetwork_iam_member(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_compute_subnetwork_pb2.ComputeSubnetworkIamMember]: ...
    @property
    def compute_subnetwork_iam_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_compute_subnetwork_pb2.ComputeSubnetworkIamPolicy]: ...
    def __init__(
        self,
        *,
        compute_subnetwork: gcp.gcp_compute_subnetwork_pb2.ComputeSubnetwork | None = ...,
        compute_subnetwork_iam_binding: collections.abc.Iterable[gcp.gcp_compute_subnetwork_pb2.ComputeSubnetworkIamBinding] | None = ...,
        compute_subnetwork_iam_member: collections.abc.Iterable[gcp.gcp_compute_subnetwork_pb2.ComputeSubnetworkIamMember] | None = ...,
        compute_subnetwork_iam_policy: collections.abc.Iterable[gcp.gcp_compute_subnetwork_pb2.ComputeSubnetworkIamPolicy] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compute_subnetwork", b"compute_subnetwork"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compute_subnetwork", b"compute_subnetwork", "compute_subnetwork_iam_binding", b"compute_subnetwork_iam_binding", "compute_subnetwork_iam_member", b"compute_subnetwork_iam_member", "compute_subnetwork_iam_policy", b"compute_subnetwork_iam_policy"]) -> None: ...

global___GoogleComputeSubnetwork = GoogleComputeSubnetwork



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_snapshot.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1egcp/gcp_compute_snapshot.proto\x12 oak9.tython.gcp.compute_snapshot\x1a\x13shared/shared.proto\"\x84\x01\n%ComputeSnapshotXSnapshotEncryptionKey\x12\x19\n\x11kms_key_self_link\x18\x01 \x01(\t\x12\x1f\n\x17kms_key_service_account\x18\x02 \x01(\t\x12\x0f\n\x07raw_key\x18\x03 \x01(\t\x12\x0e\n\x06sha256\x18\x04 \x01(\t\"[\n\'ComputeSnapshotXSourceDiskEncryptionKey\x12\x1f\n\x17kms_key_service_account\x18\x01 \x01(\t\x12\x0f\n\x07raw_key\x18\x02 \x01(\t\"J\n\x18\x43omputeSnapshotXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x8b\x06\n\x0f\x43omputeSnapshot\x12\x1a\n\x12\x63reation_timestamp\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x14\n\x0c\x64isk_size_gb\x18\x03 \x01(\x01\x12\n\n\x02id\x18\x04 \x01(\t\x12\x19\n\x11label_fingerprint\x18\x05 \x01(\t\x12M\n\x06labels\x18\x06 \x03(\x0b\x32=.oak9.tython.gcp.compute_snapshot.ComputeSnapshot.LabelsEntry\x12\x10\n\x08licenses\x18\x07 \x03(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x0f\n\x07project\x18\t \x01(\t\x12\x11\n\tself_link\x18\n \x01(\t\x12\x13\n\x0bsnapshot_id\x18\x0b \x01(\x01\x12\x13\n\x0bsource_disk\x18\x0c \x01(\t\x12\x15\n\rstorage_bytes\x18\r \x01(\x01\x12\x19\n\x11storage_locations\x18\x0e \x03(\t\x12\x0c\n\x04zone\x18\x0f \x01(\t\x12h\n\x17snapshot_encryption_key\x18\x10 \x01(\x0b\x32G.oak9.tython.gcp.compute_snapshot.ComputeSnapshotXSnapshotEncryptionKey\x12m\n\x1asource_disk_encryption_key\x18\x11 \x01(\x0b\x32I.oak9.tython.gcp.compute_snapshot.ComputeSnapshotXSourceDiskEncryptionKey\x12L\n\x08timeouts\x18\x12 \x01(\x0b\x32:.oak9.tython.gcp.compute_snapshot.ComputeSnapshotXTimeouts\x12\x37\n\rresource_info\x18\x13 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"]\n#ComputeSnapshotIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x86\x02\n\x19\x43omputeSnapshotIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07members\x18\x03 \x03(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12X\n\tcondition\x18\x07 \x01(\x0b\x32\x45.oak9.tython.gcp.compute_snapshot.ComputeSnapshotIamBindingXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\\\n\"ComputeSnapshotIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x83\x02\n\x18\x43omputeSnapshotIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06member\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12W\n\tcondition\x18\x07 \x01(\x0b\x32\x44.oak9.tython.gcp.compute_snapshot.ComputeSnapshotIamMemberXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa1\x01\n\x18\x43omputeSnapshotIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_snapshot_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTESNAPSHOT_LABELSENTRY._options = None
  _COMPUTESNAPSHOT_LABELSENTRY._serialized_options = b'8\001'
  _COMPUTESNAPSHOTXSNAPSHOTENCRYPTIONKEY._serialized_start=90
  _COMPUTESNAPSHOTXSNAPSHOTENCRYPTIONKEY._serialized_end=222
  _COMPUTESNAPSHOTXSOURCEDISKENCRYPTIONKEY._serialized_start=224
  _COMPUTESNAPSHOTXSOURCEDISKENCRYPTIONKEY._serialized_end=315
  _COMPUTESNAPSHOTXTIMEOUTS._serialized_start=317
  _COMPUTESNAPSHOTXTIMEOUTS._serialized_end=391
  _COMPUTESNAPSHOT._serialized_start=394
  _COMPUTESNAPSHOT._serialized_end=1173
  _COMPUTESNAPSHOT_LABELSENTRY._serialized_start=1128
  _COMPUTESNAPSHOT_LABELSENTRY._serialized_end=1173
  _COMPUTESNAPSHOTIAMBINDINGXCONDITION._serialized_start=1175
  _COMPUTESNAPSHOTIAMBINDINGXCONDITION._serialized_end=1268
  _COMPUTESNAPSHOTIAMBINDING._serialized_start=1271
  _COMPUTESNAPSHOTIAMBINDING._serialized_end=1533
  _COMPUTESNAPSHOTIAMMEMBERXCONDITION._serialized_start=1535
  _COMPUTESNAPSHOTIAMMEMBERXCONDITION._serialized_end=1627
  _COMPUTESNAPSHOTIAMMEMBER._serialized_start=1630
  _COMPUTESNAPSHOTIAMMEMBER._serialized_end=1889
  _COMPUTESNAPSHOTIAMPOLICY._serialized_start=1892
  _COMPUTESNAPSHOTIAMPOLICY._serialized_end=2053
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Lease(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___LeaseSpec: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___LeaseSpec | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec"]) -> None: ...

global___Lease = Lease

@typing_extensions.final
class LeaseList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Lease]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___Lease] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___LeaseList = LeaseList

@typing_extensions.final
class LeaseSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACQUIRE_TIME_FIELD_NUMBER: builtins.int
    HOLDER_IDENTITY_FIELD_NUMBER: builtins.int
    LEASE_DURATION_SECONDS_FIELD_NUMBER: builtins.int
    LEASE_TRANSITIONS_FIELD_NUMBER: builtins.int
    RENEW_TIME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def acquire_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.MicroTime: ...
    holder_identity: builtins.str
    lease_duration_seconds: builtins.int
    lease_transitions: builtins.int
    @property
    def renew_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.MicroTime: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        acquire_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.MicroTime | None = ...,
        holder_identity: builtins.str = ...,
        lease_duration_seconds: builtins.int = ...,
        lease_transitions: builtins.int = ...,
        renew_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.MicroTime | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["acquire_time", b"acquire_time", "renew_time", b"renew_time", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["acquire_time", b"acquire_time", "holder_identity", b"holder_identity", "lease_duration_seconds", b"lease_duration_seconds", "lease_transitions", b"lease_transitions", "renew_time", b"renew_time", "resource_info", b"resource_info"]) -> None: ...

global___LeaseSpec = LeaseSpec



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_compute_firewall_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_compute_firewall_pb2 as gcp_dot_gcp__compute__firewall__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,gcp/gcp_google_compute_firewall_bundle.proto\x12.oak9.tython.gcp.google_compute_firewall_bundle\x1a\x13shared/shared.proto\x1a\x1egcp/gcp_compute_firewall.proto\"d\n\x15GoogleComputeFirewall\x12K\n\x10\x63ompute_firewall\x18\x01 \x01(\x0b\x32\x31.oak9.tython.gcp.compute_firewall.ComputeFirewallb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_compute_firewall_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLECOMPUTEFIREWALL._serialized_start=149
  _GOOGLECOMPUTEFIREWALL._serialized_end=249
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ActiveDirectoryDomainXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ActiveDirectoryDomainXTimeouts = ActiveDirectoryDomainXTimeouts

@typing_extensions.final
class ActiveDirectoryDomain(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ADMIN_FIELD_NUMBER: builtins.int
    AUTHORIZED_NETWORKS_FIELD_NUMBER: builtins.int
    DOMAIN_NAME_FIELD_NUMBER: builtins.int
    FQDN_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOCATIONS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RESERVED_IP_RANGE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    admin: builtins.str
    @property
    def authorized_networks(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    domain_name: builtins.str
    fqdn: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def locations(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    name: builtins.str
    project: builtins.str
    reserved_ip_range: builtins.str
    @property
    def timeouts(self) -> global___ActiveDirectoryDomainXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        admin: builtins.str = ...,
        authorized_networks: collections.abc.Iterable[builtins.str] | None = ...,
        domain_name: builtins.str = ...,
        fqdn: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        locations: collections.abc.Iterable[builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        reserved_ip_range: builtins.str = ...,
        timeouts: global___ActiveDirectoryDomainXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["admin", b"admin", "authorized_networks", b"authorized_networks", "domain_name", b"domain_name", "fqdn", b"fqdn", "id", b"id", "labels", b"labels", "locations", b"locations", "name", b"name", "project", b"project", "reserved_ip_range", b"reserved_ip_range", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___ActiveDirectoryDomain = ActiveDirectoryDomain

@typing_extensions.final
class ActiveDirectoryDomainTrustXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ActiveDirectoryDomainTrustXTimeouts = ActiveDirectoryDomainTrustXTimeouts

@typing_extensions.final
class ActiveDirectoryDomainTrust(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOMAIN_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELECTIVE_AUTHENTICATION_FIELD_NUMBER: builtins.int
    TARGET_DNS_IP_ADDRESSES_FIELD_NUMBER: builtins.int
    TARGET_DOMAIN_NAME_FIELD_NUMBER: builtins.int
    TRUST_DIRECTION_FIELD_NUMBER: builtins.int
    TRUST_HANDSHAKE_SECRET_FIELD_NUMBER: builtins.int
    TRUST_TYPE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    domain: builtins.str
    id: builtins.str
    project: builtins.str
    selective_authentication: builtins.bool
    @property
    def target_dns_ip_addresses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    target_domain_name: builtins.str
    trust_direction: builtins.str
    trust_handshake_secret: builtins.str
    trust_type: builtins.str
    @property
    def timeouts(self) -> global___ActiveDirectoryDomainTrustXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        domain: builtins.str = ...,
        id: builtins.str = ...,
        project: builtins.str = ...,
        selective_authentication: builtins.bool = ...,
        target_dns_ip_addresses: collections.abc.Iterable[builtins.str] | None = ...,
        target_domain_name: builtins.str = ...,
        trust_direction: builtins.str = ...,
        trust_handshake_secret: builtins.str = ...,
        trust_type: builtins.str = ...,
        timeouts: global___ActiveDirectoryDomainTrustXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["domain", b"domain", "id", b"id", "project", b"project", "resource_info", b"resource_info", "selective_authentication", b"selective_authentication", "target_dns_ip_addresses", b"target_dns_ip_addresses", "target_domain_name", b"target_domain_name", "timeouts", b"timeouts", "trust_direction", b"trust_direction", "trust_handshake_secret", b"trust_handshake_secret", "trust_type", b"trust_type"]) -> None: ...

global___ActiveDirectoryDomainTrust = ActiveDirectoryDomainTrust



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_compute_network_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_compute_network_pb2 as gcp_dot_gcp__compute__network__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+gcp/gcp_google_compute_network_bundle.proto\x12-oak9.tython.gcp.google_compute_network_bundle\x1a\x13shared/shared.proto\x1a\x1dgcp/gcp_compute_network.proto\"\xac\x02\n\x14GoogleComputeNetwork\x12H\n\x0f\x63ompute_network\x18\x01 \x01(\x0b\x32/.oak9.tython.gcp.compute_network.ComputeNetwork\x12W\n\x17\x63ompute_network_peering\x18\x02 \x03(\x0b\x32\x36.oak9.tython.gcp.compute_network.ComputeNetworkPeering\x12q\n%compute_network_peering_routes_config\x18\x03 \x03(\x0b\x32\x42.oak9.tython.gcp.compute_network.ComputeNetworkPeeringRoutesConfigb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_compute_network_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLECOMPUTENETWORK._serialized_start=147
  _GOOGLECOMPUTENETWORK._serialized_end=447
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class IntOrString(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___IntOrString = IntOrString



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class IdentityPlatformDefaultSupportedIdpConfigXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___IdentityPlatformDefaultSupportedIdpConfigXTimeouts = IdentityPlatformDefaultSupportedIdpConfigXTimeouts

@typing_extensions.final
class IdentityPlatformDefaultSupportedIdpConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_ID_FIELD_NUMBER: builtins.int
    CLIENT_SECRET_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IDP_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    client_id: builtins.str
    client_secret: builtins.str
    enabled: builtins.bool
    id: builtins.str
    idp_id: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def timeouts(self) -> global___IdentityPlatformDefaultSupportedIdpConfigXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        client_id: builtins.str = ...,
        client_secret: builtins.str = ...,
        enabled: builtins.bool = ...,
        id: builtins.str = ...,
        idp_id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        timeouts: global___IdentityPlatformDefaultSupportedIdpConfigXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_id", b"client_id", "client_secret", b"client_secret", "enabled", b"enabled", "id", b"id", "idp_id", b"idp_id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___IdentityPlatformDefaultSupportedIdpConfig = IdentityPlatformDefaultSupportedIdpConfig

@typing_extensions.final
class IdentityPlatformInboundSamlConfigXIdpConfigXIdpCertificates(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    X509_CERTIFICATE_FIELD_NUMBER: builtins.int
    x509_certificate: builtins.str
    def __init__(
        self,
        *,
        x509_certificate: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["x509_certificate", b"x509_certificate"]) -> None: ...

global___IdentityPlatformInboundSamlConfigXIdpConfigXIdpCertificates = IdentityPlatformInboundSamlConfigXIdpConfigXIdpCertificates

@typing_extensions.final
class IdentityPlatformInboundSamlConfigXIdpConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDP_ENTITY_ID_FIELD_NUMBER: builtins.int
    SIGN_REQUEST_FIELD_NUMBER: builtins.int
    SSO_URL_FIELD_NUMBER: builtins.int
    IDP_CERTIFICATES_FIELD_NUMBER: builtins.int
    idp_entity_id: builtins.str
    sign_request: builtins.bool
    sso_url: builtins.str
    @property
    def idp_certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IdentityPlatformInboundSamlConfigXIdpConfigXIdpCertificates]: ...
    def __init__(
        self,
        *,
        idp_entity_id: builtins.str = ...,
        sign_request: builtins.bool = ...,
        sso_url: builtins.str = ...,
        idp_certificates: collections.abc.Iterable[global___IdentityPlatformInboundSamlConfigXIdpConfigXIdpCertificates] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["idp_certificates", b"idp_certificates", "idp_entity_id", b"idp_entity_id", "sign_request", b"sign_request", "sso_url", b"sso_url"]) -> None: ...

global___IdentityPlatformInboundSamlConfigXIdpConfig = IdentityPlatformInboundSamlConfigXIdpConfig

@typing_extensions.final
class IdentityPlatformInboundSamlConfigXSpConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SpCertificatesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CALLBACK_URI_FIELD_NUMBER: builtins.int
    SP_CERTIFICATES_FIELD_NUMBER: builtins.int
    SP_ENTITY_ID_FIELD_NUMBER: builtins.int
    callback_uri: builtins.str
    @property
    def sp_certificates(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    sp_entity_id: builtins.str
    def __init__(
        self,
        *,
        callback_uri: builtins.str = ...,
        sp_certificates: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        sp_entity_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["callback_uri", b"callback_uri", "sp_certificates", b"sp_certificates", "sp_entity_id", b"sp_entity_id"]) -> None: ...

global___IdentityPlatformInboundSamlConfigXSpConfig = IdentityPlatformInboundSamlConfigXSpConfig

@typing_extensions.final
class IdentityPlatformInboundSamlConfigXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___IdentityPlatformInboundSamlConfigXTimeouts = IdentityPlatformInboundSamlConfigXTimeouts

@typing_extensions.final
class IdentityPlatformInboundSamlConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    IDP_CONFIG_FIELD_NUMBER: builtins.int
    SP_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    display_name: builtins.str
    enabled: builtins.bool
    id: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def idp_config(self) -> global___IdentityPlatformInboundSamlConfigXIdpConfig: ...
    @property
    def sp_config(self) -> global___IdentityPlatformInboundSamlConfigXSpConfig: ...
    @property
    def timeouts(self) -> global___IdentityPlatformInboundSamlConfigXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        display_name: builtins.str = ...,
        enabled: builtins.bool = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        idp_config: global___IdentityPlatformInboundSamlConfigXIdpConfig | None = ...,
        sp_config: global___IdentityPlatformInboundSamlConfigXSpConfig | None = ...,
        timeouts: global___IdentityPlatformInboundSamlConfigXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["idp_config", b"idp_config", "resource_info", b"resource_info", "sp_config", b"sp_config", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_name", b"display_name", "enabled", b"enabled", "id", b"id", "idp_config", b"idp_config", "name", b"name", "project", b"project", "resource_info", b"resource_info", "sp_config", b"sp_config", "timeouts", b"timeouts"]) -> None: ...

global___IdentityPlatformInboundSamlConfig = IdentityPlatformInboundSamlConfig

@typing_extensions.final
class IdentityPlatformOauthIdpConfigXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___IdentityPlatformOauthIdpConfigXTimeouts = IdentityPlatformOauthIdpConfigXTimeouts

@typing_extensions.final
class IdentityPlatformOauthIdpConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_ID_FIELD_NUMBER: builtins.int
    CLIENT_SECRET_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    ISSUER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    client_id: builtins.str
    client_secret: builtins.str
    display_name: builtins.str
    enabled: builtins.bool
    id: builtins.str
    issuer: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def timeouts(self) -> global___IdentityPlatformOauthIdpConfigXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        client_id: builtins.str = ...,
        client_secret: builtins.str = ...,
        display_name: builtins.str = ...,
        enabled: builtins.bool = ...,
        id: builtins.str = ...,
        issuer: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        timeouts: global___IdentityPlatformOauthIdpConfigXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_id", b"client_id", "client_secret", b"client_secret", "display_name", b"display_name", "enabled", b"enabled", "id", b"id", "issuer", b"issuer", "name", b"name", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___IdentityPlatformOauthIdpConfig = IdentityPlatformOauthIdpConfig

@typing_extensions.final
class IdentityPlatformTenantXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___IdentityPlatformTenantXTimeouts = IdentityPlatformTenantXTimeouts

@typing_extensions.final
class IdentityPlatformTenant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_PASSWORD_SIGNUP_FIELD_NUMBER: builtins.int
    DISABLE_AUTH_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ENABLE_EMAIL_LINK_SIGNIN_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    allow_password_signup: builtins.bool
    disable_auth: builtins.bool
    display_name: builtins.str
    enable_email_link_signin: builtins.bool
    id: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def timeouts(self) -> global___IdentityPlatformTenantXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        allow_password_signup: builtins.bool = ...,
        disable_auth: builtins.bool = ...,
        display_name: builtins.str = ...,
        enable_email_link_signin: builtins.bool = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        timeouts: global___IdentityPlatformTenantXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_password_signup", b"allow_password_signup", "disable_auth", b"disable_auth", "display_name", b"display_name", "enable_email_link_signin", b"enable_email_link_signin", "id", b"id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___IdentityPlatformTenant = IdentityPlatformTenant

@typing_extensions.final
class IdentityPlatformTenantDefaultSupportedIdpConfigXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___IdentityPlatformTenantDefaultSupportedIdpConfigXTimeouts = IdentityPlatformTenantDefaultSupportedIdpConfigXTimeouts

@typing_extensions.final
class IdentityPlatformTenantDefaultSupportedIdpConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_ID_FIELD_NUMBER: builtins.int
    CLIENT_SECRET_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IDP_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TENANT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    client_id: builtins.str
    client_secret: builtins.str
    enabled: builtins.bool
    id: builtins.str
    idp_id: builtins.str
    name: builtins.str
    project: builtins.str
    tenant: builtins.str
    @property
    def timeouts(self) -> global___IdentityPlatformTenantDefaultSupportedIdpConfigXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        client_id: builtins.str = ...,
        client_secret: builtins.str = ...,
        enabled: builtins.bool = ...,
        id: builtins.str = ...,
        idp_id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        tenant: builtins.str = ...,
        timeouts: global___IdentityPlatformTenantDefaultSupportedIdpConfigXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_id", b"client_id", "client_secret", b"client_secret", "enabled", b"enabled", "id", b"id", "idp_id", b"idp_id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "tenant", b"tenant", "timeouts", b"timeouts"]) -> None: ...

global___IdentityPlatformTenantDefaultSupportedIdpConfig = IdentityPlatformTenantDefaultSupportedIdpConfig

@typing_extensions.final
class IdentityPlatformTenantInboundSamlConfigXIdpConfigXIdpCertificates(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    X509_CERTIFICATE_FIELD_NUMBER: builtins.int
    x509_certificate: builtins.str
    def __init__(
        self,
        *,
        x509_certificate: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["x509_certificate", b"x509_certificate"]) -> None: ...

global___IdentityPlatformTenantInboundSamlConfigXIdpConfigXIdpCertificates = IdentityPlatformTenantInboundSamlConfigXIdpConfigXIdpCertificates

@typing_extensions.final
class IdentityPlatformTenantInboundSamlConfigXIdpConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDP_ENTITY_ID_FIELD_NUMBER: builtins.int
    SIGN_REQUEST_FIELD_NUMBER: builtins.int
    SSO_URL_FIELD_NUMBER: builtins.int
    IDP_CERTIFICATES_FIELD_NUMBER: builtins.int
    idp_entity_id: builtins.str
    sign_request: builtins.bool
    sso_url: builtins.str
    @property
    def idp_certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IdentityPlatformTenantInboundSamlConfigXIdpConfigXIdpCertificates]: ...
    def __init__(
        self,
        *,
        idp_entity_id: builtins.str = ...,
        sign_request: builtins.bool = ...,
        sso_url: builtins.str = ...,
        idp_certificates: collections.abc.Iterable[global___IdentityPlatformTenantInboundSamlConfigXIdpConfigXIdpCertificates] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["idp_certificates", b"idp_certificates", "idp_entity_id", b"idp_entity_id", "sign_request", b"sign_request", "sso_url", b"sso_url"]) -> None: ...

global___IdentityPlatformTenantInboundSamlConfigXIdpConfig = IdentityPlatformTenantInboundSamlConfigXIdpConfig

@typing_extensions.final
class IdentityPlatformTenantInboundSamlConfigXSpConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SpCertificatesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CALLBACK_URI_FIELD_NUMBER: builtins.int
    SP_CERTIFICATES_FIELD_NUMBER: builtins.int
    SP_ENTITY_ID_FIELD_NUMBER: builtins.int
    callback_uri: builtins.str
    @property
    def sp_certificates(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    sp_entity_id: builtins.str
    def __init__(
        self,
        *,
        callback_uri: builtins.str = ...,
        sp_certificates: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        sp_entity_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["callback_uri", b"callback_uri", "sp_certificates", b"sp_certificates", "sp_entity_id", b"sp_entity_id"]) -> None: ...

global___IdentityPlatformTenantInboundSamlConfigXSpConfig = IdentityPlatformTenantInboundSamlConfigXSpConfig

@typing_extensions.final
class IdentityPlatformTenantInboundSamlConfigXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___IdentityPlatformTenantInboundSamlConfigXTimeouts = IdentityPlatformTenantInboundSamlConfigXTimeouts

@typing_extensions.final
class IdentityPlatformTenantInboundSamlConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TENANT_FIELD_NUMBER: builtins.int
    IDP_CONFIG_FIELD_NUMBER: builtins.int
    SP_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    display_name: builtins.str
    enabled: builtins.bool
    id: builtins.str
    name: builtins.str
    project: builtins.str
    tenant: builtins.str
    @property
    def idp_config(self) -> global___IdentityPlatformTenantInboundSamlConfigXIdpConfig: ...
    @property
    def sp_config(self) -> global___IdentityPlatformTenantInboundSamlConfigXSpConfig: ...
    @property
    def timeouts(self) -> global___IdentityPlatformTenantInboundSamlConfigXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        display_name: builtins.str = ...,
        enabled: builtins.bool = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        tenant: builtins.str = ...,
        idp_config: global___IdentityPlatformTenantInboundSamlConfigXIdpConfig | None = ...,
        sp_config: global___IdentityPlatformTenantInboundSamlConfigXSpConfig | None = ...,
        timeouts: global___IdentityPlatformTenantInboundSamlConfigXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["idp_config", b"idp_config", "resource_info", b"resource_info", "sp_config", b"sp_config", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_name", b"display_name", "enabled", b"enabled", "id", b"id", "idp_config", b"idp_config", "name", b"name", "project", b"project", "resource_info", b"resource_info", "sp_config", b"sp_config", "tenant", b"tenant", "timeouts", b"timeouts"]) -> None: ...

global___IdentityPlatformTenantInboundSamlConfig = IdentityPlatformTenantInboundSamlConfig

@typing_extensions.final
class IdentityPlatformTenantOauthIdpConfigXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___IdentityPlatformTenantOauthIdpConfigXTimeouts = IdentityPlatformTenantOauthIdpConfigXTimeouts

@typing_extensions.final
class IdentityPlatformTenantOauthIdpConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_ID_FIELD_NUMBER: builtins.int
    CLIENT_SECRET_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    ISSUER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TENANT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    client_id: builtins.str
    client_secret: builtins.str
    display_name: builtins.str
    enabled: builtins.bool
    id: builtins.str
    issuer: builtins.str
    name: builtins.str
    project: builtins.str
    tenant: builtins.str
    @property
    def timeouts(self) -> global___IdentityPlatformTenantOauthIdpConfigXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        client_id: builtins.str = ...,
        client_secret: builtins.str = ...,
        display_name: builtins.str = ...,
        enabled: builtins.bool = ...,
        id: builtins.str = ...,
        issuer: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        tenant: builtins.str = ...,
        timeouts: global___IdentityPlatformTenantOauthIdpConfigXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_id", b"client_id", "client_secret", b"client_secret", "display_name", b"display_name", "enabled", b"enabled", "id", b"id", "issuer", b"issuer", "name", b"name", "project", b"project", "resource_info", b"resource_info", "tenant", b"tenant", "timeouts", b"timeouts"]) -> None: ...

global___IdentityPlatformTenantOauthIdpConfig = IdentityPlatformTenantOauthIdpConfig



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_packet.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cgcp/gcp_compute_packet.proto\x12\x1eoak9.tython.gcp.compute_packet\x1a\x13shared/shared.proto\"2\n#ComputePacketMirroringXCollectorIlb\x12\x0b\n\x03url\x18\x01 \x01(\t\"]\n\x1d\x43omputePacketMirroringXFilter\x12\x13\n\x0b\x63idr_ranges\x18\x01 \x03(\t\x12\x11\n\tdirection\x18\x02 \x01(\t\x12\x14\n\x0cip_protocols\x18\x03 \x03(\t\"A\n2ComputePacketMirroringXMirroredResourcesXInstances\x12\x0b\n\x03url\x18\x01 \x01(\t\"C\n4ComputePacketMirroringXMirroredResourcesXSubnetworks\x12\x0b\n\x03url\x18\x01 \x01(\t\"\x8a\x02\n(ComputePacketMirroringXMirroredResources\x12\x0c\n\x04tags\x18\x01 \x03(\t\x12\x65\n\tinstances\x18\x02 \x03(\x0b\x32R.oak9.tython.gcp.compute_packet.ComputePacketMirroringXMirroredResourcesXInstances\x12i\n\x0bsubnetworks\x18\x03 \x03(\x0b\x32T.oak9.tython.gcp.compute_packet.ComputePacketMirroringXMirroredResourcesXSubnetworks\"-\n\x1e\x43omputePacketMirroringXNetwork\x12\x0b\n\x03url\x18\x01 \x01(\t\"Q\n\x1f\x43omputePacketMirroringXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xe8\x04\n\x16\x43omputePacketMirroring\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08priority\x18\x04 \x01(\x01\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12Z\n\rcollector_ilb\x18\x07 \x01(\x0b\x32\x43.oak9.tython.gcp.compute_packet.ComputePacketMirroringXCollectorIlb\x12M\n\x06\x66ilter\x18\x08 \x01(\x0b\x32=.oak9.tython.gcp.compute_packet.ComputePacketMirroringXFilter\x12\x64\n\x12mirrored_resources\x18\t \x01(\x0b\x32H.oak9.tython.gcp.compute_packet.ComputePacketMirroringXMirroredResources\x12O\n\x07network\x18\n \x01(\x0b\x32>.oak9.tython.gcp.compute_packet.ComputePacketMirroringXNetwork\x12Q\n\x08timeouts\x18\x0b \x01(\x0b\x32?.oak9.tython.gcp.compute_packet.ComputePacketMirroringXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_packet_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEPACKETMIRRORINGXCOLLECTORILB._serialized_start=85
  _COMPUTEPACKETMIRRORINGXCOLLECTORILB._serialized_end=135
  _COMPUTEPACKETMIRRORINGXFILTER._serialized_start=137
  _COMPUTEPACKETMIRRORINGXFILTER._serialized_end=230
  _COMPUTEPACKETMIRRORINGXMIRROREDRESOURCESXINSTANCES._serialized_start=232
  _COMPUTEPACKETMIRRORINGXMIRROREDRESOURCESXINSTANCES._serialized_end=297
  _COMPUTEPACKETMIRRORINGXMIRROREDRESOURCESXSUBNETWORKS._serialized_start=299
  _COMPUTEPACKETMIRRORINGXMIRROREDRESOURCESXSUBNETWORKS._serialized_end=366
  _COMPUTEPACKETMIRRORINGXMIRROREDRESOURCES._serialized_start=369
  _COMPUTEPACKETMIRRORINGXMIRROREDRESOURCES._serialized_end=635
  _COMPUTEPACKETMIRRORINGXNETWORK._serialized_start=637
  _COMPUTEPACKETMIRRORINGXNETWORK._serialized_end=682
  _COMPUTEPACKETMIRRORINGXTIMEOUTS._serialized_start=684
  _COMPUTEPACKETMIRRORINGXTIMEOUTS._serialized_end=765
  _COMPUTEPACKETMIRRORING._serialized_start=768
  _COMPUTEPACKETMIRRORING._serialized_end=1384
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_containerservice.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,azure/azure_microsoft_containerservice.proto\x12,oak9.tython.azure.microsoft_containerservice\x1a\x13shared/shared.proto\"\xe4\x01\n\x1aMicrosoft_ContainerService\x12W\n\x10managed_clusters\x18\x01 \x01(\x0b\x32=.oak9.tython.azure.microsoft_containerservice.ManagedClusters\x12m\n\x1cmanaged_clusters_agent_pools\x18\x02 \x03(\x0b\x32G.oak9.tython.azure.microsoft_containerservice.ManagedClustersAgentPools\"\xcc\x02\n\tSnapshots\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12Q\n\rcreation_data\x18\x04 \x01(\x0b\x32:.oak9.tython.azure.microsoft_containerservice.CreationData\x12\x15\n\rsnapshot_type\x18\x05 \x01(\t\x12O\n\x04tags\x18\x06 \x03(\x0b\x32\x41.oak9.tython.azure.microsoft_containerservice.Snapshots.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xcb\x02\n)ManagedClustersPrivateEndpointConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12W\n\x10private_endpoint\x18\x03 \x01(\x0b\x32=.oak9.tython.azure.microsoft_containerservice.PrivateEndpoint\x12~\n%private_link_service_connection_state\x18\x04 \x01(\x0b\x32O.oak9.tython.azure.microsoft_containerservice.PrivateLinkServiceConnectionState\"H\n!PrivateLinkServiceConnectionState\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\"\x1d\n\x0fPrivateEndpoint\x12\n\n\x02id\x18\x01 \x01(\t\"\x93\x02\n(ManagedClustersMaintenanceConfigurations\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12P\n\x10not_allowed_time\x18\x03 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_containerservice.TimeSpan\x12N\n\x0ctime_in_week\x18\x04 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_containerservice.TimeInWeek\"-\n\nTimeInWeek\x12\x0b\n\x03\x64\x61y\x18\x01 \x01(\t\x12\x12\n\nhour_slots\x18\x02 \x03(\x05\"&\n\x08TimeSpan\x12\x0b\n\x03\x65nd\x18\x01 \x01(\t\x12\r\n\x05start\x18\x02 \x01(\t\"\xf5\x0c\n\x19ManagedClustersAgentPools\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1a\n\x12\x61vailability_zones\x18\x03 \x03(\t\x12%\n\x1d\x63\x61pacity_reservation_group_id\x18\x04 \x01(\t\x12\r\n\x05\x63ount\x18\x05 \x01(\x05\x12Q\n\rcreation_data\x18\x06 \x01(\x0b\x32:.oak9.tython.azure.microsoft_containerservice.CreationData\x12\x1b\n\x13\x65nable_auto_scaling\x18\x07 \x01(\x08\x12!\n\x19\x65nable_encryption_at_host\x18\x08 \x01(\x08\x12\x13\n\x0b\x65nable_fips\x18\t \x01(\x08\x12\x1d\n\x15\x65nable_node_public_ip\x18\n \x01(\x08\x12\x18\n\x10\x65nable_ultra_ssd\x18\x0b \x01(\x08\x12\x1c\n\x14gpu_instance_profile\x18\x0c \x01(\t\x12\x15\n\rhost_group_id\x18\r \x01(\t\x12S\n\x0ekubelet_config\x18\x0e \x01(\x0b\x32;.oak9.tython.azure.microsoft_containerservice.KubeletConfig\x12\x19\n\x11kubelet_disk_type\x18\x0f \x01(\t\x12T\n\x0flinux_os_config\x18\x10 \x01(\x0b\x32;.oak9.tython.azure.microsoft_containerservice.LinuxOSConfig\x12\x11\n\tmax_count\x18\x11 \x01(\x05\x12\x10\n\x08max_pods\x18\x12 \x01(\x05\x12\x1a\n\x12message_of_the_day\x18\x13 \x01(\t\x12\x11\n\tmin_count\x18\x14 \x01(\x05\x12\x0c\n\x04mode\x18\x15 \x01(\t\x12l\n\x0bnode_labels\x18\x16 \x03(\x0b\x32W.oak9.tython.azure.microsoft_containerservice.ManagedClustersAgentPools.NodeLabelsEntry\x12 \n\x18node_public_ip_prefix_id\x18\x17 \x01(\t\x12\x13\n\x0bnode_taints\x18\x18 \x03(\t\x12\x1c\n\x14orchestrator_version\x18\x19 \x01(\t\x12\x17\n\x0fos_disk_size_gb\x18\x1a \x01(\x05\x12\x14\n\x0cos_disk_type\x18\x1b \x01(\t\x12\x0e\n\x06os_sku\x18\x1c \x01(\t\x12\x0f\n\x07os_type\x18\x1d \x01(\t\x12\x15\n\rpod_subnet_id\x18\x1e \x01(\t\x12M\n\x0bpower_state\x18\x1f \x01(\x0b\x32\x38.oak9.tython.azure.microsoft_containerservice.PowerState\x12$\n\x1cproximity_placement_group_id\x18  \x01(\t\x12\x17\n\x0fscale_down_mode\x18! \x01(\t\x12!\n\x19scale_set_eviction_policy\x18\" \x01(\t\x12\x1a\n\x12scale_set_priority\x18# \x01(\t\x12\x16\n\x0espot_max_price\x18$ \x01(\x01\x12_\n\x04tags\x18% \x03(\x0b\x32Q.oak9.tython.azure.microsoft_containerservice.ManagedClustersAgentPools.TagsEntry\x12\x0c\n\x04type\x18& \x01(\t\x12`\n\x10upgrade_settings\x18\' \x01(\x0b\x32\x46.oak9.tython.azure.microsoft_containerservice.AgentPoolUpgradeSettings\x12\x0f\n\x07vm_size\x18( \x01(\t\x12\x16\n\x0evnet_subnet_id\x18) \x01(\t\x12\x18\n\x10workload_runtime\x18* \x01(\t\x1a\x31\n\x0fNodeLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xcb\x16\n\x0fManagedClusters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Y\n\x11\x65xtended_location\x18\x02 \x01(\x0b\x32>.oak9.tython.azure.microsoft_containerservice.ExtendedLocation\x12V\n\x08identity\x18\x03 \x01(\x0b\x32\x44.oak9.tython.azure.microsoft_containerservice.ManagedClusterIdentity\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12[\n\x0b\x61\x61\x64_profile\x18\x06 \x01(\x0b\x32\x46.oak9.tython.azure.microsoft_containerservice.ManagedClusterAADProfile\x12h\n\x0e\x61\x64\x64on_profiles\x18\x07 \x03(\x0b\x32P.oak9.tython.azure.microsoft_containerservice.ManagedClusters.AddonProfilesEntry\x12i\n\x13\x61gent_pool_profiles\x18\x08 \x03(\x0b\x32L.oak9.tython.azure.microsoft_containerservice.ManagedClusterAgentPoolProfile\x12u\n\x19\x61pi_server_access_profile\x18\t \x01(\x0b\x32R.oak9.tython.azure.microsoft_containerservice.ManagedClusterAPIServerAccessProfile\x12t\n\x13\x61uto_scaler_profile\x18\n \x01(\x0b\x32W.oak9.tython.azure.microsoft_containerservice.ManagedClusterPropertiesAutoScalerProfile\x12l\n\x14\x61uto_upgrade_profile\x18\x0b \x01(\x0b\x32N.oak9.tython.azure.microsoft_containerservice.ManagedClusterAutoUpgradeProfile\x12\x1e\n\x16\x64isable_local_accounts\x18\x0c \x01(\x08\x12\x1e\n\x16\x64isk_encryption_set_id\x18\r \x01(\t\x12\x12\n\ndns_prefix\x18\x0e \x01(\t\x12\"\n\x1a\x65nable_namespace_resources\x18\x0f \x01(\x08\x12\"\n\x1a\x65nable_pod_security_policy\x18\x10 \x01(\x08\x12\x13\n\x0b\x65nable_rbac\x18\x11 \x01(\x08\x12\x16\n\x0e\x66qdn_subdomain\x18\x12 \x01(\t\x12\x66\n\x11http_proxy_config\x18\x13 \x01(\x0b\x32K.oak9.tython.azure.microsoft_containerservice.ManagedClusterHTTPProxyConfig\x12l\n\x10identity_profile\x18\x14 \x03(\x0b\x32R.oak9.tython.azure.microsoft_containerservice.ManagedClusters.IdentityProfileEntry\x12\x1a\n\x12kubernetes_version\x18\x15 \x01(\t\x12\x61\n\rlinux_profile\x18\x16 \x01(\x0b\x32J.oak9.tython.azure.microsoft_containerservice.ContainerServiceLinuxProfile\x12\x65\n\x0fnetwork_profile\x18\x17 \x01(\x0b\x32L.oak9.tython.azure.microsoft_containerservice.ContainerServiceNetworkProfile\x12\x1b\n\x13node_resource_group\x18\x18 \x01(\t\x12j\n\x13oidc_issuer_profile\x18\x19 \x01(\x0b\x32M.oak9.tython.azure.microsoft_containerservice.ManagedClusterOIDCIssuerProfile\x12l\n\x14pod_identity_profile\x18\x1a \x01(\x0b\x32N.oak9.tython.azure.microsoft_containerservice.ManagedClusterPodIdentityProfile\x12\x61\n\x16private_link_resources\x18\x1b \x03(\x0b\x32\x41.oak9.tython.azure.microsoft_containerservice.PrivateLinkResource\x12\x1d\n\x15public_network_access\x18\x1c \x01(\t\x12\x65\n\x10security_profile\x18\x1d \x01(\x0b\x32K.oak9.tython.azure.microsoft_containerservice.ManagedClusterSecurityProfile\x12v\n\x19service_principal_profile\x18\x1e \x01(\x0b\x32S.oak9.tython.azure.microsoft_containerservice.ManagedClusterServicePrincipalProfile\x12\x63\n\x0fwindows_profile\x18\x1f \x01(\x0b\x32J.oak9.tython.azure.microsoft_containerservice.ManagedClusterWindowsProfile\x12L\n\x03sku\x18  \x01(\x0b\x32?.oak9.tython.azure.microsoft_containerservice.ManagedClusterSKU\x12U\n\x04tags\x18! \x03(\x0b\x32G.oak9.tython.azure.microsoft_containerservice.ManagedClusters.TagsEntry\x12\x8b\x01\n+managed_clusters_maintenance_configurations\x18\" \x03(\x0b\x32V.oak9.tython.azure.microsoft_containerservice.ManagedClustersMaintenanceConfigurations\x12\x8e\x01\n-managed_clusters_private_endpoint_connections\x18# \x03(\x0b\x32W.oak9.tython.azure.microsoft_containerservice.ManagedClustersPrivateEndpointConnections\x1a\x34\n\x12\x41\x64\x64onProfilesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x36\n\x14IdentityProfileEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"/\n\x11ManagedClusterSKU\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04tier\x18\x02 \x01(\t\"\xd6\x01\n\x1cManagedClusterWindowsProfile\x12\x16\n\x0e\x61\x64min_password\x18\x01 \x01(\t\x12\x16\n\x0e\x61\x64min_username\x18\x02 \x01(\t\x12\x18\n\x10\x65nable_cs_iproxy\x18\x03 \x01(\x08\x12V\n\x0cgmsa_profile\x18\x04 \x01(\x0b\x32@.oak9.tython.azure.microsoft_containerservice.WindowsGmsaProfile\x12\x14\n\x0clicense_type\x18\x05 \x01(\t\"S\n\x12WindowsGmsaProfile\x12\x12\n\ndns_server\x18\x01 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x18\n\x10root_domain_name\x18\x03 \x01(\t\"J\n%ManagedClusterServicePrincipalProfile\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x0e\n\x06secret\x18\x02 \x01(\t\"\x91\x01\n\x1dManagedClusterSecurityProfile\x12p\n\x0e\x61zure_defender\x18\x01 \x01(\x0b\x32X.oak9.tython.azure.microsoft_containerservice.ManagedClusterSecurityProfileAzureDefender\"j\n*ManagedClusterSecurityProfileAzureDefender\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12+\n#log_analytics_workspace_resource_id\x18\x02 \x01(\t\"i\n\x13PrivateLinkResource\x12\x10\n\x08group_id\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x18\n\x10required_members\x18\x04 \x03(\t\x12\x0c\n\x04type\x18\x05 \x01(\t\"\xc1\x02\n ManagedClusterPodIdentityProfile\x12$\n\x1c\x61llow_network_plugin_kubenet\x18\x01 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12i\n\x18user_assigned_identities\x18\x03 \x03(\x0b\x32G.oak9.tython.azure.microsoft_containerservice.ManagedClusterPodIdentity\x12{\n!user_assigned_identity_exceptions\x18\x04 \x03(\x0b\x32P.oak9.tython.azure.microsoft_containerservice.ManagedClusterPodIdentityException\"\xec\x01\n\"ManagedClusterPodIdentityException\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12s\n\npod_labels\x18\x03 \x03(\x0b\x32_.oak9.tython.azure.microsoft_containerservice.ManagedClusterPodIdentityException.PodLabelsEntry\x1a\x30\n\x0ePodLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xac\x01\n\x19ManagedClusterPodIdentity\x12\x18\n\x10\x62inding_selector\x18\x01 \x01(\t\x12T\n\x08identity\x18\x02 \x01(\x0b\x32\x42.oak9.tython.azure.microsoft_containerservice.UserAssignedIdentity\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tnamespace\x18\x04 \x01(\t\"Q\n\x14UserAssignedIdentity\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x11\n\tobject_id\x18\x02 \x01(\t\x12\x13\n\x0bresource_id\x18\x03 \x01(\t\"2\n\x1fManagedClusterOIDCIssuerProfile\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"\x8f\x04\n\x1e\x43ontainerServiceNetworkProfile\x12\x16\n\x0e\x64ns_service_ip\x18\x01 \x01(\t\x12\x1a\n\x12\x64ocker_bridge_cidr\x18\x02 \x01(\t\x12\x13\n\x0bip_families\x18\x03 \x03(\t\x12n\n\x15load_balancer_profile\x18\x04 \x01(\x0b\x32O.oak9.tython.azure.microsoft_containerservice.ManagedClusterLoadBalancerProfile\x12\x19\n\x11load_balancer_sku\x18\x05 \x01(\t\x12j\n\x13nat_gateway_profile\x18\x06 \x01(\x0b\x32M.oak9.tython.azure.microsoft_containerservice.ManagedClusterNATGatewayProfile\x12\x14\n\x0cnetwork_mode\x18\x07 \x01(\t\x12\x16\n\x0enetwork_plugin\x18\x08 \x01(\t\x12\x16\n\x0enetwork_policy\x18\t \x01(\t\x12\x15\n\routbound_type\x18\n \x01(\t\x12\x10\n\x08pod_cidr\x18\x0b \x01(\t\x12\x11\n\tpod_cidrs\x18\x0c \x03(\t\x12\x14\n\x0cservice_cidr\x18\r \x01(\t\x12\x15\n\rservice_cidrs\x18\x0e \x03(\t\"\x9e\x02\n\x1fManagedClusterNATGatewayProfile\x12_\n\x16\x65\x66\x66\x65\x63tive_outbound_ips\x18\x01 \x03(\x0b\x32?.oak9.tython.azure.microsoft_containerservice.ResourceReference\x12\x1f\n\x17idle_timeout_in_minutes\x18\x02 \x01(\x05\x12y\n\x1bmanaged_outbound_ip_profile\x18\x03 \x01(\x0b\x32T.oak9.tython.azure.microsoft_containerservice.ManagedClusterManagedOutboundIPProfile\"7\n&ManagedClusterManagedOutboundIPProfile\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\"\xec\x04\n!ManagedClusterLoadBalancerProfile\x12 \n\x18\x61llocated_outbound_ports\x18\x01 \x01(\x05\x12_\n\x16\x65\x66\x66\x65\x63tive_outbound_ips\x18\x02 \x03(\x0b\x32?.oak9.tython.azure.microsoft_containerservice.ResourceReference\x12/\n\'enable_multiple_standard_load_balancers\x18\x03 \x01(\x08\x12\x1f\n\x17idle_timeout_in_minutes\x18\x04 \x01(\x05\x12\x7f\n\x14managed_outbound_ips\x18\x05 \x01(\x0b\x32\x61.oak9.tython.azure.microsoft_containerservice.ManagedClusterLoadBalancerProfileManagedOutboundIPs\x12\x7f\n\x14outbound_ip_prefixes\x18\x06 \x01(\x0b\x32\x61.oak9.tython.azure.microsoft_containerservice.ManagedClusterLoadBalancerProfileOutboundIPPrefixes\x12p\n\x0coutbound_ips\x18\x07 \x01(\x0b\x32Z.oak9.tython.azure.microsoft_containerservice.ManagedClusterLoadBalancerProfileOutboundIPs\"\x83\x01\n,ManagedClusterLoadBalancerProfileOutboundIPs\x12S\n\npublic_ips\x18\x01 \x03(\x0b\x32?.oak9.tython.azure.microsoft_containerservice.ResourceReference\"\x92\x01\n3ManagedClusterLoadBalancerProfileOutboundIPPrefixes\x12[\n\x12public_ip_prefixes\x18\x01 \x03(\x0b\x32?.oak9.tython.azure.microsoft_containerservice.ResourceReference\"X\n3ManagedClusterLoadBalancerProfileManagedOutboundIPs\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\x12\x12\n\ncount_ipv6\x18\x02 \x01(\x05\"\x1f\n\x11ResourceReference\x12\n\n\x02id\x18\x01 \x01(\t\"\x93\x01\n\x1c\x43ontainerServiceLinuxProfile\x12\x16\n\x0e\x61\x64min_username\x18\x01 \x01(\t\x12[\n\x03ssh\x18\x02 \x01(\x0b\x32N.oak9.tython.azure.microsoft_containerservice.ContainerServiceSshConfiguration\"\x83\x01\n ContainerServiceSshConfiguration\x12_\n\x0bpublic_keys\x18\x01 \x03(\x0b\x32J.oak9.tython.azure.microsoft_containerservice.ContainerServiceSshPublicKey\"0\n\x1c\x43ontainerServiceSshPublicKey\x12\x10\n\x08key_data\x18\x01 \x01(\t\"n\n\x1dManagedClusterHTTPProxyConfig\x12\x12\n\nhttp_proxy\x18\x01 \x01(\t\x12\x13\n\x0bhttps_proxy\x18\x02 \x01(\t\x12\x10\n\x08no_proxy\x18\x03 \x03(\t\x12\x12\n\ntrusted_ca\x18\x04 \x01(\t\";\n ManagedClusterAutoUpgradeProfile\x12\x17\n\x0fupgrade_channel\x18\x01 \x01(\t\"\xf1\x04\n)ManagedClusterPropertiesAutoScalerProfile\x12#\n\x1b\x62\x61lance_similar_node_groups\x18\x01 \x01(\t\x12\x10\n\x08\x65xpander\x18\x02 \x01(\t\x12\x1d\n\x15max_empty_bulk_delete\x18\x03 \x01(\t\x12$\n\x1cmax_graceful_termination_sec\x18\x04 \x01(\t\x12\x1f\n\x17max_node_provision_time\x18\x05 \x01(\t\x12$\n\x1cmax_total_unready_percentage\x18\x06 \x01(\t\x12\x1e\n\x16new_pod_scale_up_delay\x18\x07 \x01(\t\x12\x1e\n\x16ok_total_unready_count\x18\x08 \x01(\t\x12\"\n\x1ascale_down_delay_after_add\x18\t \x01(\t\x12%\n\x1dscale_down_delay_after_delete\x18\n \x01(\t\x12&\n\x1escale_down_delay_after_failure\x18\x0b \x01(\t\x12 \n\x18scale_down_unneeded_time\x18\x0c \x01(\t\x12\x1f\n\x17scale_down_unready_time\x18\r \x01(\t\x12(\n scale_down_utilization_threshold\x18\x0e \x01(\t\x12\x15\n\rscan_interval\x18\x0f \x01(\t\x12%\n\x1dskip_nodes_with_local_storage\x18\x10 \x01(\t\x12#\n\x1bskip_nodes_with_system_pods\x18\x11 \x01(\t\"\xc7\x01\n$ManagedClusterAPIServerAccessProfile\x12\x1c\n\x14\x61uthorized_ip_ranges\x18\x01 \x03(\t\x12\x1b\n\x13\x64isable_run_command\x18\x02 \x01(\x08\x12\x1e\n\x16\x65nable_private_cluster\x18\x03 \x01(\x08\x12*\n\"enable_private_cluster_public_fqdn\x18\x04 \x01(\x08\x12\x18\n\x10private_dns_zone\x18\x05 \x01(\t\"\xcb\x0c\n\x1eManagedClusterAgentPoolProfile\x12\x1a\n\x12\x61vailability_zones\x18\x01 \x03(\t\x12%\n\x1d\x63\x61pacity_reservation_group_id\x18\x02 \x01(\t\x12\r\n\x05\x63ount\x18\x03 \x01(\x05\x12Q\n\rcreation_data\x18\x04 \x01(\x0b\x32:.oak9.tython.azure.microsoft_containerservice.CreationData\x12\x1b\n\x13\x65nable_auto_scaling\x18\x05 \x01(\x08\x12!\n\x19\x65nable_encryption_at_host\x18\x06 \x01(\x08\x12\x13\n\x0b\x65nable_fips\x18\x07 \x01(\x08\x12\x1d\n\x15\x65nable_node_public_ip\x18\x08 \x01(\x08\x12\x18\n\x10\x65nable_ultra_ssd\x18\t \x01(\x08\x12\x1c\n\x14gpu_instance_profile\x18\n \x01(\t\x12\x15\n\rhost_group_id\x18\x0b \x01(\t\x12S\n\x0ekubelet_config\x18\x0c \x01(\x0b\x32;.oak9.tython.azure.microsoft_containerservice.KubeletConfig\x12\x19\n\x11kubelet_disk_type\x18\r \x01(\t\x12T\n\x0flinux_os_config\x18\x0e \x01(\x0b\x32;.oak9.tython.azure.microsoft_containerservice.LinuxOSConfig\x12\x11\n\tmax_count\x18\x0f \x01(\x05\x12\x10\n\x08max_pods\x18\x10 \x01(\x05\x12\x1a\n\x12message_of_the_day\x18\x11 \x01(\t\x12\x11\n\tmin_count\x18\x12 \x01(\x05\x12\x0c\n\x04mode\x18\x13 \x01(\t\x12\x0c\n\x04name\x18\x14 \x01(\t\x12q\n\x0bnode_labels\x18\x15 \x03(\x0b\x32\\.oak9.tython.azure.microsoft_containerservice.ManagedClusterAgentPoolProfile.NodeLabelsEntry\x12 \n\x18node_public_ip_prefix_id\x18\x16 \x01(\t\x12\x13\n\x0bnode_taints\x18\x17 \x03(\t\x12\x1c\n\x14orchestrator_version\x18\x18 \x01(\t\x12\x17\n\x0fos_disk_size_gb\x18\x19 \x01(\x05\x12\x14\n\x0cos_disk_type\x18\x1a \x01(\t\x12\x0e\n\x06os_sku\x18\x1b \x01(\t\x12\x0f\n\x07os_type\x18\x1c \x01(\t\x12\x15\n\rpod_subnet_id\x18\x1d \x01(\t\x12M\n\x0bpower_state\x18\x1e \x01(\x0b\x32\x38.oak9.tython.azure.microsoft_containerservice.PowerState\x12$\n\x1cproximity_placement_group_id\x18\x1f \x01(\t\x12\x17\n\x0fscale_down_mode\x18  \x01(\t\x12!\n\x19scale_set_eviction_policy\x18! \x01(\t\x12\x1a\n\x12scale_set_priority\x18\" \x01(\t\x12\x16\n\x0espot_max_price\x18# \x01(\x01\x12\x64\n\x04tags\x18$ \x03(\x0b\x32V.oak9.tython.azure.microsoft_containerservice.ManagedClusterAgentPoolProfile.TagsEntry\x12\x0c\n\x04type\x18% \x01(\t\x12`\n\x10upgrade_settings\x18& \x01(\x0b\x32\x46.oak9.tython.azure.microsoft_containerservice.AgentPoolUpgradeSettings\x12\x0f\n\x07vm_size\x18\' \x01(\t\x12\x16\n\x0evnet_subnet_id\x18( \x01(\t\x12\x18\n\x10workload_runtime\x18) \x01(\t\x1a\x31\n\x0fNodeLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"-\n\x18\x41gentPoolUpgradeSettings\x12\x11\n\tmax_surge\x18\x01 \x01(\t\"\x1a\n\nPowerState\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\"\xc4\x01\n\rLinuxOSConfig\x12\x19\n\x11swap_file_size_mb\x18\x01 \x01(\x05\x12K\n\x07sysctls\x18\x02 \x01(\x0b\x32:.oak9.tython.azure.microsoft_containerservice.SysctlConfig\x12$\n\x1ctransparent_huge_page_defrag\x18\x03 \x01(\t\x12%\n\x1dtransparent_huge_page_enabled\x18\x04 \x01(\t\"\xa9\x07\n\x0cSysctlConfig\x12\x15\n\rfs_aio_max_nr\x18\x01 \x01(\x05\x12\x13\n\x0b\x66s_file_max\x18\x02 \x01(\x05\x12#\n\x1b\x66s_inotify_max_user_watches\x18\x03 \x01(\x05\x12\x12\n\nfs_nr_open\x18\x04 \x01(\x05\x12\x1a\n\x12kernel_threads_max\x18\x05 \x01(\x05\x12#\n\x1bnet_core_netdev_max_backlog\x18\x06 \x01(\x05\x12\x1b\n\x13net_core_optmem_max\x18\x07 \x01(\x05\x12\x1d\n\x15net_core_rmem_default\x18\x08 \x01(\x05\x12\x19\n\x11net_core_rmem_max\x18\t \x01(\x05\x12\x1a\n\x12net_core_somaxconn\x18\n \x01(\x05\x12\x1d\n\x15net_core_wmem_default\x18\x0b \x01(\x05\x12\x19\n\x11net_core_wmem_max\x18\x0c \x01(\x05\x12$\n\x1cnet_ipv4_ip_local_port_range\x18\r \x01(\t\x12)\n!net_ipv4_neigh_default_gc_thresh1\x18\x0e \x01(\x05\x12)\n!net_ipv4_neigh_default_gc_thresh2\x18\x0f \x01(\x05\x12)\n!net_ipv4_neigh_default_gc_thresh3\x18\x10 \x01(\x05\x12 \n\x18net_ipv4_tcp_fin_timeout\x18\x11 \x01(\x05\x12#\n\x1bnet_ipv4_tcpkeepalive_intvl\x18\x12 \x01(\x05\x12%\n\x1dnet_ipv4_tcp_keepalive_probes\x18\x13 \x01(\x05\x12#\n\x1bnet_ipv4_tcp_keepalive_time\x18\x14 \x01(\x05\x12$\n\x1cnet_ipv4_tcp_max_syn_backlog\x18\x15 \x01(\x05\x12#\n\x1bnet_ipv4_tcp_max_tw_buckets\x18\x16 \x01(\x05\x12\x1d\n\x15net_ipv4_tcp_tw_reuse\x18\x17 \x01(\x08\x12*\n\"net_netfilter_nf_conntrack_buckets\x18\x18 \x01(\x05\x12&\n\x1enet_netfilter_nf_conntrack_max\x18\x19 \x01(\x05\x12\x18\n\x10vm_max_map_count\x18\x1a \x01(\x05\x12\x15\n\rvm_swappiness\x18\x1b \x01(\x05\x12\x1d\n\x15vm_vfs_cache_pressure\x18\x1c \x01(\x05\"\xd2\x02\n\rKubeletConfig\x12\x1e\n\x16\x61llowed_unsafe_sysctls\x18\x01 \x03(\t\x12\x1f\n\x17\x63ontainer_log_max_files\x18\x02 \x01(\x05\x12!\n\x19\x63ontainer_log_max_size_mb\x18\x03 \x01(\x05\x12\x15\n\rcpu_cfs_quota\x18\x04 \x01(\x08\x12\x1c\n\x14\x63pu_cfs_quota_period\x18\x05 \x01(\t\x12\x1a\n\x12\x63pu_manager_policy\x18\x06 \x01(\t\x12\x14\n\x0c\x66\x61il_swap_on\x18\x07 \x01(\x08\x12\x1f\n\x17image_gc_high_threshold\x18\x08 \x01(\x05\x12\x1e\n\x16image_gc_low_threshold\x18\t \x01(\x05\x12\x14\n\x0cpod_max_pids\x18\n \x01(\x05\x12\x1f\n\x17topology_manager_policy\x18\x0b \x01(\t\"*\n\x0c\x43reationData\x12\x1a\n\x12source_resource_id\x18\x01 \x01(\t\"\xc2\x01\n\x18ManagedClusterAADProfile\x12\x1e\n\x16\x61\x64min_group_object_ids\x18\x01 \x03(\t\x12\x15\n\rclient_app_id\x18\x02 \x01(\t\x12\x19\n\x11\x65nable_azure_rbac\x18\x03 \x01(\x08\x12\x0f\n\x07managed\x18\x04 \x01(\x08\x12\x15\n\rserver_app_id\x18\x05 \x01(\t\x12\x19\n\x11server_app_secret\x18\x06 \x01(\t\x12\x11\n\ttenant_id\x18\x07 \x01(\t\"\xea\x01\n\x16ManagedClusterIdentity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x82\x01\n\x18user_assigned_identities\x18\x02 \x03(\x0b\x32`.oak9.tython.azure.microsoft_containerservice.ManagedClusterIdentity.UserAssignedIdentitiesEntry\x1a=\n\x1bUserAssignedIdentitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\".\n\x10\x45xtendedLocation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_containerservice_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SNAPSHOTS_TAGSENTRY._options = None
  _SNAPSHOTS_TAGSENTRY._serialized_options = b'8\001'
  _MANAGEDCLUSTERSAGENTPOOLS_NODELABELSENTRY._options = None
  _MANAGEDCLUSTERSAGENTPOOLS_NODELABELSENTRY._serialized_options = b'8\001'
  _MANAGEDCLUSTERSAGENTPOOLS_TAGSENTRY._options = None
  _MANAGEDCLUSTERSAGENTPOOLS_TAGSENTRY._serialized_options = b'8\001'
  _MANAGEDCLUSTERS_ADDONPROFILESENTRY._options = None
  _MANAGEDCLUSTERS_ADDONPROFILESENTRY._serialized_options = b'8\001'
  _MANAGEDCLUSTERS_IDENTITYPROFILEENTRY._options = None
  _MANAGEDCLUSTERS_IDENTITYPROFILEENTRY._serialized_options = b'8\001'
  _MANAGEDCLUSTERS_TAGSENTRY._options = None
  _MANAGEDCLUSTERS_TAGSENTRY._serialized_options = b'8\001'
  _MANAGEDCLUSTERPODIDENTITYEXCEPTION_PODLABELSENTRY._options = None
  _MANAGEDCLUSTERPODIDENTITYEXCEPTION_PODLABELSENTRY._serialized_options = b'8\001'
  _MANAGEDCLUSTERAGENTPOOLPROFILE_NODELABELSENTRY._options = None
  _MANAGEDCLUSTERAGENTPOOLPROFILE_NODELABELSENTRY._serialized_options = b'8\001'
  _MANAGEDCLUSTERAGENTPOOLPROFILE_TAGSENTRY._options = None
  _MANAGEDCLUSTERAGENTPOOLPROFILE_TAGSENTRY._serialized_options = b'8\001'
  _MANAGEDCLUSTERIDENTITY_USERASSIGNEDIDENTITIESENTRY._options = None
  _MANAGEDCLUSTERIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_options = b'8\001'
  _MICROSOFT_CONTAINERSERVICE._serialized_start=116
  _MICROSOFT_CONTAINERSERVICE._serialized_end=344
  _SNAPSHOTS._serialized_start=347
  _SNAPSHOTS._serialized_end=679
  _SNAPSHOTS_TAGSENTRY._serialized_start=636
  _SNAPSHOTS_TAGSENTRY._serialized_end=679
  _MANAGEDCLUSTERSPRIVATEENDPOINTCONNECTIONS._serialized_start=682
  _MANAGEDCLUSTERSPRIVATEENDPOINTCONNECTIONS._serialized_end=1013
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_start=1015
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_end=1087
  _PRIVATEENDPOINT._serialized_start=1089
  _PRIVATEENDPOINT._serialized_end=1118
  _MANAGEDCLUSTERSMAINTENANCECONFIGURATIONS._serialized_start=1121
  _MANAGEDCLUSTERSMAINTENANCECONFIGURATIONS._serialized_end=1396
  _TIMEINWEEK._serialized_start=1398
  _TIMEINWEEK._serialized_end=1443
  _TIMESPAN._serialized_start=1445
  _TIMESPAN._serialized_end=1483
  _MANAGEDCLUSTERSAGENTPOOLS._serialized_start=1486
  _MANAGEDCLUSTERSAGENTPOOLS._serialized_end=3139
  _MANAGEDCLUSTERSAGENTPOOLS_NODELABELSENTRY._serialized_start=3045
  _MANAGEDCLUSTERSAGENTPOOLS_NODELABELSENTRY._serialized_end=3094
  _MANAGEDCLUSTERSAGENTPOOLS_TAGSENTRY._serialized_start=636
  _MANAGEDCLUSTERSAGENTPOOLS_TAGSENTRY._serialized_end=679
  _MANAGEDCLUSTERS._serialized_start=3142
  _MANAGEDCLUSTERS._serialized_end=6033
  _MANAGEDCLUSTERS_ADDONPROFILESENTRY._serialized_start=5880
  _MANAGEDCLUSTERS_ADDONPROFILESENTRY._serialized_end=5932
  _MANAGEDCLUSTERS_IDENTITYPROFILEENTRY._serialized_start=5934
  _MANAGEDCLUSTERS_IDENTITYPROFILEENTRY._serialized_end=5988
  _MANAGEDCLUSTERS_TAGSENTRY._serialized_start=636
  _MANAGEDCLUSTERS_TAGSENTRY._serialized_end=679
  _MANAGEDCLUSTERSKU._serialized_start=6035
  _MANAGEDCLUSTERSKU._serialized_end=6082
  _MANAGEDCLUSTERWINDOWSPROFILE._serialized_start=6085
  _MANAGEDCLUSTERWINDOWSPROFILE._serialized_end=6299
  _WINDOWSGMSAPROFILE._serialized_start=6301
  _WINDOWSGMSAPROFILE._serialized_end=6384
  _MANAGEDCLUSTERSERVICEPRINCIPALPROFILE._serialized_start=6386
  _MANAGEDCLUSTERSERVICEPRINCIPALPROFILE._serialized_end=6460
  _MANAGEDCLUSTERSECURITYPROFILE._serialized_start=6463
  _MANAGEDCLUSTERSECURITYPROFILE._serialized_end=6608
  _MANAGEDCLUSTERSECURITYPROFILEAZUREDEFENDER._serialized_start=6610
  _MANAGEDCLUSTERSECURITYPROFILEAZUREDEFENDER._serialized_end=6716
  _PRIVATELINKRESOURCE._serialized_start=6718
  _PRIVATELINKRESOURCE._serialized_end=6823
  _MANAGEDCLUSTERPODIDENTITYPROFILE._serialized_start=6826
  _MANAGEDCLUSTERPODIDENTITYPROFILE._serialized_end=7147
  _MANAGEDCLUSTERPODIDENTITYEXCEPTION._serialized_start=7150
  _MANAGEDCLUSTERPODIDENTITYEXCEPTION._serialized_end=7386
  _MANAGEDCLUSTERPODIDENTITYEXCEPTION_PODLABELSENTRY._serialized_start=7338
  _MANAGEDCLUSTERPODIDENTITYEXCEPTION_PODLABELSENTRY._serialized_end=7386
  _MANAGEDCLUSTERPODIDENTITY._serialized_start=7389
  _MANAGEDCLUSTERPODIDENTITY._serialized_end=7561
  _USERASSIGNEDIDENTITY._serialized_start=7563
  _USERASSIGNEDIDENTITY._serialized_end=7644
  _MANAGEDCLUSTEROIDCISSUERPROFILE._serialized_start=7646
  _MANAGEDCLUSTEROIDCISSUERPROFILE._serialized_end=7696
  _CONTAINERSERVICENETWORKPROFILE._serialized_start=7699
  _CONTAINERSERVICENETWORKPROFILE._serialized_end=8226
  _MANAGEDCLUSTERNATGATEWAYPROFILE._serialized_start=8229
  _MANAGEDCLUSTERNATGATEWAYPROFILE._serialized_end=8515
  _MANAGEDCLUSTERMANAGEDOUTBOUNDIPPROFILE._serialized_start=8517
  _MANAGEDCLUSTERMANAGEDOUTBOUNDIPPROFILE._serialized_end=8572
  _MANAGEDCLUSTERLOADBALANCERPROFILE._serialized_start=8575
  _MANAGEDCLUSTERLOADBALANCERPROFILE._serialized_end=9195
  _MANAGEDCLUSTERLOADBALANCERPROFILEOUTBOUNDIPS._serialized_start=9198
  _MANAGEDCLUSTERLOADBALANCERPROFILEOUTBOUNDIPS._serialized_end=9329
  _MANAGEDCLUSTERLOADBALANCERPROFILEOUTBOUNDIPPREFIXES._serialized_start=9332
  _MANAGEDCLUSTERLOADBALANCERPROFILEOUTBOUNDIPPREFIXES._serialized_end=9478
  _MANAGEDCLUSTERLOADBALANCERPROFILEMANAGEDOUTBOUNDIPS._serialized_start=9480
  _MANAGEDCLUSTERLOADBALANCERPROFILEMANAGEDOUTBOUNDIPS._serialized_end=9568
  _RESOURCEREFERENCE._serialized_start=9570
  _RESOURCEREFERENCE._serialized_end=9601
  _CONTAINERSERVICELINUXPROFILE._serialized_start=9604
  _CONTAINERSERVICELINUXPROFILE._serialized_end=9751
  _CONTAINERSERVICESSHCONFIGURATION._serialized_start=9754
  _CONTAINERSERVICESSHCONFIGURATION._serialized_end=9885
  _CONTAINERSERVICESSHPUBLICKEY._serialized_start=9887
  _CONTAINERSERVICESSHPUBLICKEY._serialized_end=9935
  _MANAGEDCLUSTERHTTPPROXYCONFIG._serialized_start=9937
  _MANAGEDCLUSTERHTTPPROXYCONFIG._serialized_end=10047
  _MANAGEDCLUSTERAUTOUPGRADEPROFILE._serialized_start=10049
  _MANAGEDCLUSTERAUTOUPGRADEPROFILE._serialized_end=10108
  _MANAGEDCLUSTERPROPERTIESAUTOSCALERPROFILE._serialized_start=10111
  _MANAGEDCLUSTERPROPERTIESAUTOSCALERPROFILE._serialized_end=10736
  _MANAGEDCLUSTERAPISERVERACCESSPROFILE._serialized_start=10739
  _MANAGEDCLUSTERAPISERVERACCESSPROFILE._serialized_end=10938
  _MANAGEDCLUSTERAGENTPOOLPROFILE._serialized_start=10941
  _MANAGEDCLUSTERAGENTPOOLPROFILE._serialized_end=12552
  _MANAGEDCLUSTERAGENTPOOLPROFILE_NODELABELSENTRY._serialized_start=3045
  _MANAGEDCLUSTERAGENTPOOLPROFILE_NODELABELSENTRY._serialized_end=3094
  _MANAGEDCLUSTERAGENTPOOLPROFILE_TAGSENTRY._serialized_start=636
  _MANAGEDCLUSTERAGENTPOOLPROFILE_TAGSENTRY._serialized_end=679
  _AGENTPOOLUPGRADESETTINGS._serialized_start=12554
  _AGENTPOOLUPGRADESETTINGS._serialized_end=12599
  _POWERSTATE._serialized_start=12601
  _POWERSTATE._serialized_end=12627
  _LINUXOSCONFIG._serialized_start=12630
  _LINUXOSCONFIG._serialized_end=12826
  _SYSCTLCONFIG._serialized_start=12829
  _SYSCTLCONFIG._serialized_end=13766
  _KUBELETCONFIG._serialized_start=13769
  _KUBELETCONFIG._serialized_end=14107
  _CREATIONDATA._serialized_start=14109
  _CREATIONDATA._serialized_end=14151
  _MANAGEDCLUSTERAADPROFILE._serialized_start=14154
  _MANAGEDCLUSTERAADPROFILE._serialized_end=14348
  _MANAGEDCLUSTERIDENTITY._serialized_start=14351
  _MANAGEDCLUSTERIDENTITY._serialized_end=14585
  _MANAGEDCLUSTERIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_start=14524
  _MANAGEDCLUSTERIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_end=14585
  _EXTENDEDLOCATION._serialized_start=14587
  _EXTENDEDLOCATION._serialized_end=14633
# @@protoc_insertion_point(module_scope)
